Welcome to SlideSeg, a python module that allows you to segment whole slide images into usable image chips for deep learning. Image masks for each chip are generated from associated markup and annotation files.

Complete documentation can be found at https://github.com/btcrabb/SlideSeg